@@ -1,10 +1,10 @@
 package App::Info::Request;
 
-# $Id: Request.pm,v 1.8 2002/06/30 22:18:41 david Exp $
+# $Id: Request.pm,v 1.10 2002/08/08 19:19:18 david Exp $
 
 =head1 NAME
 
-App::Info::Handler - App::Info event handler request object
+App::Info::Request - App::Info event handler request object
 
 =head1 SYNOPSIS
 
@@ -44,7 +44,7 @@ to handle the request appropriately.
 
 use strict;
 use vars qw($VERSION);
-$VERSION = '0.21';
+$VERSION = '0.22';
 
 ##############################################################################
 
@@ -248,8 +248,8 @@ __END__
 
 =head1 BUGS
 
-I suppose it's possible that there are bugs in this code. Drop me an email if
-you happen to discover any.
+Report all bugs via the CPAN Request Tracker at
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=App-Info>.
 
 =head1 AUTHOR
 
